BrLogTheme class final
Tema de cores ANSI e ícones usado pelos printers do pacote.
Cores dependem do terminal. BrDeveloperOutput entrega eventos para
dart:developer, portanto a apresentação final fica a cargo do DevTools,
Xcode ou IDE e não dos códigos ANSI deste tema.
Constructors
- BrLogTheme({String traceColor = BrAnsiColor.gray, String debugColor = BrAnsiColor.blue, String infoColor = BrAnsiColor.green, String warningColor = BrAnsiColor.yellow, String errorColor = BrAnsiColor.red, String fatalColor = BrAnsiColor.boldRed, String resetColor = BrAnsiColor.reset, String traceIcon = '·', String debugIcon = '◆', String infoIcon = 'ℹ', String warningIcon = '⚠', String errorIcon = '✖', String fatalIcon = '‼'})
-
const
Properties
- debugColor → String
-
final
- debugIcon → String
-
final
- errorColor → String
-
final
- errorIcon → String
-
final
- fatalColor → String
-
final
- fatalIcon → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- infoColor → String
-
final
- infoIcon → String
-
final
- resetColor → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- traceColor → String
-
final
- traceIcon → String
-
final
- warningColor → String
-
final
- warningIcon → String
-
final
Methods
-
colorFor(
BrLogLevel level) → String -
iconFor(
BrLogLevel level) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited